<?php

function limeslice_after_setup_theme() {
    global $content_width;

    if (!isset($content_width)) {
        $content_width = 450;
    }

    add_editor_style('editor-style.css');

    register_nav_menu('main', 'Main navigation menu');

    add_theme_support('html5');
    add_theme_support('automatic-feed-links');
    add_theme_support('post-thumbnails');
    add_theme_support('custom-header', array(
        'default-image' => get_template_directory_uri() . '/images/header.jpg',
        'width'  => 680,
        'height' => 140,
        'default-text-color' => 'ffffff',
        'wp-head-callback' => 'limeslice_header_style',
    ));
    add_theme_support('custom-background', array(
        'wp-head-callback' => 'limeslice_custom_background',
    ));
}
add_action('after_setup_theme', 'limeslice_after_setup_theme');

add_action( 'widgets_init', 'limeslice_widgets_init' );
function limeslice_widgets_init() {
    register_sidebar( array(
        'name'  => 'Sidebar',
        'id'    => 'sidebar',
        'description'   => 'Right Sidebar',
        'before_title'=>'<h3>',
        'after_title'=>'</h3>',
        'before_widget'=>'<div class="box">',
        'after_widget'=>'</div>'
    ) );
}

function limeslice_wp_enqueue_scripts() {

    wp_enqueue_style( 'limeslice', get_stylesheet_uri() );

    wp_register_style('limeslice-ie', get_template_directory_uri().'/ie.css');

    $GLOBALS['wp_styles']->add_data( 'limeslice-ie', 'conditional', 'lte IE 8' );

    wp_enqueue_style('limeslice-ie');

    if ( is_singular() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action('wp_enqueue_scripts', 'limeslice_wp_enqueue_scripts');

function limeslice_custom_background() {
    /* Get the background image. */
    $image = get_background_image();
    /* If there's an image, just call the normal WordPress callback. We won't do anything here. */
    if ( !empty( $image ) ) {
            _custom_background_cb();
            return;
    }
    /* Get the background color. */
    $color = get_background_color();
    /* If no background color, return. */
    if ( empty( $color ) )
            return;
    /* Use 'background' instead of 'background-color'. */
    $style = "background: #{$color};";
?>
<style type="text/css">body { <?php echo trim( $style ); ?> }</style>
<?php
}

function limeslice_header_style() {
    ?><style type="text/css">
        <?php if (get_header_image()) : ?>
            #header {
                background: url(<?php header_image(); ?>) no-repeat;
            }
        <?php endif; ?>
        <?php if (get_header_textcolor()) : ?>
            #header h1 a,
            #header .description {
                color: #<?php header_textcolor();?>;
            }
        <?php endif; ?>
    </style><?php
}

function limeslice_remove_width_attribute( $html ) {
   $html = preg_replace( '/(width|height)="\d*"\s/', "", $html );
   return $html;
}
add_filter( 'post_thumbnail_html', 'limeslice_remove_width_attribute', 10 );
add_filter( 'image_send_to_editor', 'limeslice_remove_width_attribute', 10 );

function limeslice_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) {
        return $title;
    }

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) ) {
        $title = "$title $sep $site_description";
    }

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 ) {
        $title = "$title $sep " . sprintf( __( 'Page %s', 'twentyfourteen' ), max( $paged, $page ) );
    }

    return $title;
}
add_filter( 'wp_title', 'limeslice_wp_title', 10, 2 );
